@@ -1,4 +1,4 @@
-from django.contrib.auth import get_user_model
+from django.conf import settings
 from django.core.mail import EmailMultiAlternatives
 from django.db import models
 from django.template import Context
@@ -14,9 +14,6 @@ import logging
 import requests
 
 
-User = get_user_model()
-
-
 class NotificationChannels(models.IntegerChoices):
     PUSH = 100, "push"
     EMAIL = 200, "email"
@@ -47,7 +44,7 @@ class NotificationHistory(AbstractNotificationBase):
     )
     timestamp = models.DateTimeField(auto_now=True)
     users = models.ManyToManyField(
-        User, help_text="Users this notification was sent to"
+        settings.AUTH_USER_MODEL, help_text="Users this notification was sent to"
     )
 
     class Meta:
